# pulp_npm-client
Fetch, Upload, Organize, and Distribute Software Packages

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.1.0a1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pulpcore.client.pulp_npm
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pulpcore.client.pulp_npm
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import pulpcore.client.pulp_npm
from pulpcore.client.pulp_npm.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://pulp
# See configuration.py for a list of all supported configuration parameters.
configuration = pulpcore.client.pulp_npm.Configuration(
    host = "http://pulp"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = pulpcore.client.pulp_npm.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure API key authorization: cookieAuth
configuration = pulpcore.client.pulp_npm.Configuration(
    host = "http://pulp",
    api_key = {
        'Session': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Session'] = 'Bearer'


# Enter a context with an instance of the API client
with pulpcore.client.pulp_npm.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pulpcore.client.pulp_npm.ContentPackagesApi(api_client)
    relative_path = 'relative_path_example' # str | 
name = 'name_example' # str | 
version = 'version_example' # str | 
artifact = 'artifact_example' # str | Artifact file representing the physical content (optional)
file = '/path/to/file' # file | An uploaded file that may be turned into the artifact of the content unit. (optional)
repository = 'repository_example' # str | A URI of a repository the new content unit should be associated with. (optional)

    try:
        # Create a package
        api_response = api_instance.create(relative_path, name, version, artifact=artifact, file=file, repository=repository)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ContentPackagesApi->create: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ContentPackagesApi* | [**create**](docs/ContentPackagesApi.md#create) | **POST** /pulp/api/v3/content/npm/packages/ | Create a package
*ContentPackagesApi* | [**list**](docs/ContentPackagesApi.md#list) | **GET** /pulp/api/v3/content/npm/packages/ | List packages
*ContentPackagesApi* | [**read**](docs/ContentPackagesApi.md#read) | **GET** {npm_package_href} | Inspect a package
*DistributionsNpmApi* | [**create**](docs/DistributionsNpmApi.md#create) | **POST** /pulp/api/v3/distributions/npm/npm/ | Create a npm distribution
*DistributionsNpmApi* | [**delete**](docs/DistributionsNpmApi.md#delete) | **DELETE** {npm_npm_distribution_href} | Delete a npm distribution
*DistributionsNpmApi* | [**list**](docs/DistributionsNpmApi.md#list) | **GET** /pulp/api/v3/distributions/npm/npm/ | List npm distributions
*DistributionsNpmApi* | [**partial_update**](docs/DistributionsNpmApi.md#partial_update) | **PATCH** {npm_npm_distribution_href} | Update a npm distribution
*DistributionsNpmApi* | [**read**](docs/DistributionsNpmApi.md#read) | **GET** {npm_npm_distribution_href} | Inspect a npm distribution
*DistributionsNpmApi* | [**update**](docs/DistributionsNpmApi.md#update) | **PUT** {npm_npm_distribution_href} | Update a npm distribution
*PulpNpmPackagesApi* | [**get**](docs/PulpNpmPackagesApi.md#get) | **GET** /pulp_npm/packages/{name}/ | 
*RemotesNpmApi* | [**create**](docs/RemotesNpmApi.md#create) | **POST** /pulp/api/v3/remotes/npm/npm/ | Create a npm remote
*RemotesNpmApi* | [**delete**](docs/RemotesNpmApi.md#delete) | **DELETE** {npm_npm_remote_href} | Delete a npm remote
*RemotesNpmApi* | [**list**](docs/RemotesNpmApi.md#list) | **GET** /pulp/api/v3/remotes/npm/npm/ | List npm remotes
*RemotesNpmApi* | [**partial_update**](docs/RemotesNpmApi.md#partial_update) | **PATCH** {npm_npm_remote_href} | Update a npm remote
*RemotesNpmApi* | [**read**](docs/RemotesNpmApi.md#read) | **GET** {npm_npm_remote_href} | Inspect a npm remote
*RemotesNpmApi* | [**update**](docs/RemotesNpmApi.md#update) | **PUT** {npm_npm_remote_href} | Update a npm remote
*RepositoriesNpmApi* | [**create**](docs/RepositoriesNpmApi.md#create) | **POST** /pulp/api/v3/repositories/npm/npm/ | Create a npm repository
*RepositoriesNpmApi* | [**delete**](docs/RepositoriesNpmApi.md#delete) | **DELETE** {npm_npm_repository_href} | Delete a npm repository
*RepositoriesNpmApi* | [**list**](docs/RepositoriesNpmApi.md#list) | **GET** /pulp/api/v3/repositories/npm/npm/ | List npm repositorys
*RepositoriesNpmApi* | [**modify**](docs/RepositoriesNpmApi.md#modify) | **POST** {npm_npm_repository_href}modify/ | Modify Repository Content
*RepositoriesNpmApi* | [**partial_update**](docs/RepositoriesNpmApi.md#partial_update) | **PATCH** {npm_npm_repository_href} | Update a npm repository
*RepositoriesNpmApi* | [**read**](docs/RepositoriesNpmApi.md#read) | **GET** {npm_npm_repository_href} | Inspect a npm repository
*RepositoriesNpmApi* | [**sync**](docs/RepositoriesNpmApi.md#sync) | **POST** {npm_npm_repository_href}sync/ | Sync from remote
*RepositoriesNpmApi* | [**update**](docs/RepositoriesNpmApi.md#update) | **PUT** {npm_npm_repository_href} | Update a npm repository
*RepositoriesNpmVersionsApi* | [**delete**](docs/RepositoriesNpmVersionsApi.md#delete) | **DELETE** {npm_npm_repository_version_href} | Delete a repository version
*RepositoriesNpmVersionsApi* | [**list**](docs/RepositoriesNpmVersionsApi.md#list) | **GET** {npm_npm_repository_href}versions/ | List repository versions
*RepositoriesNpmVersionsApi* | [**read**](docs/RepositoriesNpmVersionsApi.md#read) | **GET** {npm_npm_repository_version_href} | Inspect a repository version
*RepositoriesNpmVersionsApi* | [**repair**](docs/RepositoriesNpmVersionsApi.md#repair) | **POST** {npm_npm_repository_version_href}repair/ | 


## Documentation For Models

 - [AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [ContentSummary](docs/ContentSummary.md)
 - [ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [NpmNpmDistribution](docs/NpmNpmDistribution.md)
 - [NpmNpmDistributionResponse](docs/NpmNpmDistributionResponse.md)
 - [NpmNpmRemote](docs/NpmNpmRemote.md)
 - [NpmNpmRemoteResponse](docs/NpmNpmRemoteResponse.md)
 - [NpmNpmRepository](docs/NpmNpmRepository.md)
 - [NpmNpmRepositoryResponse](docs/NpmNpmRepositoryResponse.md)
 - [NpmPackage](docs/NpmPackage.md)
 - [NpmPackageResponse](docs/NpmPackageResponse.md)
 - [PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PaginatednpmNpmDistributionResponseList](docs/PaginatednpmNpmDistributionResponseList.md)
 - [PaginatednpmNpmRemoteResponseList](docs/PaginatednpmNpmRemoteResponseList.md)
 - [PaginatednpmNpmRepositoryResponseList](docs/PaginatednpmNpmRepositoryResponseList.md)
 - [PaginatednpmPackageResponseList](docs/PaginatednpmPackageResponseList.md)
 - [PatchednpmNpmDistribution](docs/PatchednpmNpmDistribution.md)
 - [PatchednpmNpmRemote](docs/PatchednpmNpmRemote.md)
 - [PatchednpmNpmRepository](docs/PatchednpmNpmRepository.md)
 - [PolicyEnum](docs/PolicyEnum.md)
 - [RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [RepositorySyncURL](docs/RepositorySyncURL.md)
 - [RepositoryVersion](docs/RepositoryVersion.md)
 - [RepositoryVersionResponse](docs/RepositoryVersionResponse.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## cookieAuth

- **Type**: API key
- **API key parameter name**: Session
- **Location**: 


## Author

pulp-list@redhat.com


